/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "{0}, the {1}. of {2}"
: "{0}, o {1}. de {2}"

, "Recurrances"
: "Recorrências"

, "No recurring rule defined"
: "Nenhuma regra recorrente definida"

, "Details"
: "Detalhes"

, "None"
: "Nenhum"

, "Daily"
: "Diariamente"

, "Weekly"
: "Semanalmente"

, "Monthly"
: "Mensalmente"

, "Yearly"
: "Anualmente"

, "Exceptions of reccuring events can't have recurrences themselves."
: "Exceções de eventos recorrentes não podem ter recorrências deles mesmos."

, "at"
: "em"

, "never"
: "nunca"

, "after {0} occurrences"
: "após {0} ocorrências"

, "Except"
: "Exceto"

, "during events in the calendars"
: "durante eventos nos calendários"

, "End"
: "Fim"

, "Until has to be after event start"
: "Até que esteja após o início do evento"

, "The event is longer than the recurring interval"
: "O evento é maior do que o intervalo de recorrência"

, "Every {0}. Day"
: "Cada {0}. Dia"

, "Every {0}. Week at"
: "Cada {0}. Semana em"

, "Every {0}. Month"
: "Cada {0}. Mes"

, "at the"
: "no"

, "first"
: "primeiro"

, "second"
: "segundo"

, "third"
: "terceiro"

, "fourth"
: "quarto"

, "last"
: "último"

, "Every {0}. Year"
: "Cada {0}. Ano"

, "of"
: "de"

, "Summary"
: "Sumário"

, "Organizer"
: "Organizador"

, "Description"
: "Descrição"

, "Location"
: "Locação"

, "Start Time"
: "Hora de Início"

, "End Time"
: "Hora Final"

, "Attendee"
: "Participante"

, "whole day"
: "dia inteiro"

, "Week {0} :"
: "Semana {0} :"

, "Poll, Polls"
: [
  ""
 ,""

]
, "Options"
: ""

, "Alternative Dates"
: ""

, "Set as definite event"
: ""

, "Create Poll for this Event"
: ""

, "Name for poll"
: ""

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: ""

, "Share the link below to poll for attendee status feedback."
: ""

, "Public URL"
: ""

, "Protect poll with a password"
: ""

, "Only invited attendee can reply"
: ""

, "Start Date"
: ""

, "Info"
: ""

, "loading alternative dates"
: ""

, "Select one Event Only"
: ""

, "You need to select exactly one event as the definite event."
: ""

, "Setting definite event"
: ""

, "New Event"
: "Novo Evento"

, "Calendar, Calendars"
: [
  "Calendário"
 ,"Calendários"

]
, "Event not found"
: ""

, "The Event was deleted in the meantime or you don't have access rights to it."
: ""

, "Switch to public poll"
: ""

, "Welcome {name}"
: ""

, "This is a closed poll. No Attendee can be added."
: ""

, "This poll is closed already"
: ""

, "I am not {name}"
: ""

, "Login"
: ""

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Cancel"
: "Cancelar"

, "Save"
: ""

, "By using this service you agree to our terms and conditions"
: ""

, "Use your personal link please."
: ""

, "We have sent it to your E-Mail account again."
: ""

, "If you did not receive the link, please contact the organiser."
: ""

, "Password"
: "Senha"

, "Submit"
: ""

, "Wrong password!"
: ""

, "Please log in"
: ""

, "User name"
: ""

, "Calendar of {name}"
: ""

, "An unexpected error occurred."
: ""

, "Add attendee"
: "Adicionar participante"

, "Sort Attendee"
: "Tipo do Participante"

, "Check to filter for this attendee"
: "Verifique antes de filtrar este participante"

, "Unavailable"
: ""

, "Loading events, please wait..."
: "Carregando eventos, favor aguardar..."

, "Cut event"
: "Cortar evento"

, "Copy Event to clipboard"
: "Copiar evento para área de transferecia"

, "Stop cut / copy & paste"
: ""

, "Print Page"
: "Imprimir Página"

, "Loose-Leaf"
: ""

, "Sheet"
: "Folha"

, "Grid"
: "Grade"

, "Timeline"
: ""

, "Day"
: "Dia"

, "Week"
: "Semana"

, "Month"
: "Mes"

, "Year"
: "Ano"

, "Custom Selection"
: ""

, "Import Events"
: "Importar Eventos"

, "Paste event \"{0}\""
: ""

, "Set my response"
: "Assinale minha resposta"

, "Copy {0}"
: "Copiar {0}"

, "Set event status"
: ""

, "Updating event in the past"
: "Atualizando evento na pasta"

, "Update this event"
: "Atualizar este evento"

, "Do not update this event"
: "Não atualize este evento"

, "Creating event in the past"
: "Criando evento no passado"

, "Create this event"
: "Criar este evento"

, "Do not create this event"
: "Não criar este evento"

, "Update this event only"
: "Atualizar somente este evento"

, "Update this and all future events"
: "Atualizar este e todos os eventos futuros"

, "Update whole series"
: "Atualizar séries inteiras"

, "Update nothing"
: "Não atualizar nada"

, "Update Event"
: "Atualizar Evento"

, "Please Change Selection"
: "Favor Modificar a Seleção"

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: "Sua seleção contém eventos recorrentes. Eventos recorrentes devem ser apagados separadamente!"

, "Delete Event"
: "Apagar Evento"

, "Delete this event only"
: "Apagar somente este evento"

, "Delete this and all future events"
: "Apagar este e todos os eventos futuros"

, "Delete whole series"
: "Apagar séries inteiras"

, "Delete nothing"
: "Não apagar nada"

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  "Você quer realmente apagar este evento?"
 ,"Você quer realmente apagar os {0} eventos selecionados?"

]
, "Could not Print"
: "Não é possível Imprimir"

, "Sorry, your current view does not support printing."
: "Desculpe, mas sua visão atual não permite impressão."

, "Scheduling Conflict"
: "Conflito de Agendamento"

, "The following attendee are busy at the requested time:"
: "O seguinte participante está ocupado na hora solicitada:"

, "Ignore Conflict"
: "Ignorar Conflito"

, "Edit Event"
: "Editar Evento"

, "Cancel this action"
: "Cancelar esta ação"

, "Update Status for all Attendee?"
: ""

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: ""

, "Manage Resources"
: "Administrar Recursos"

, "GENDER_Attendee"
: ""

, "Select Attendee"
: "Selecionar Participante"

, "Attachments"
: ""

, "Private"
: "Privado"

, "Tags"
: "Identificações"

, "Blocking"
: "Bloqueando"

, "Tentative"
: "Tentativa"

, "Import Definition Success!"
: ""

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: ""

, "Choose Import File"
: ""

, "Please choose the file that contains the records you want to add to Tine 2.0"
: ""

, "Select file containing your {0}"
: ""

, "once"
: "uma vez"

, "hourly"
: ""

, "daily"
: "diariamente"

, "weekly"
: "semanalmente"

, "Choose Remote Location"
: ""

, "Please choose a remote location you want to add to Tine 2.0"
: ""

, "Username"
: ""

, "Refresh time"
: ""

, "General Settings"
: ""

, "Calendar name (you need permissions to add events)"
: ""

, "What should the file you upload look like?"
: ""

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: ""

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: ""

, "Please select the import format of the file you want to upload"
: ""

, "Download example file"
: ""

, "Remote / ICS"
: "ICS / Remoto"

, "Remote / CalDAV (BETA)"
: ""

, "Upload"
: ""

, "Choose File and Format"
: ""

, "Select type of source"
: ""

, "Please select the type of source you want to add to Tine 2.0"
: ""

, "Importing {0}"
: ""

, "Back"
: ""

, "Next"
: ""

, "Ok"
: "OK"

, "Free Time Search"
: ""

, "Searching for Free Time..."
: ""

, "No Free Time found"
: ""

, "No free timeslot could be found Until {0}. Do you want to continue?"
: ""

, "Continue"
: ""

, "Give up"
: ""

, "Free Time Search Options"
: ""

, "private classification"
: "classificação privada"

, "recurring event"
: "evento recorrente"

, "recurring event exception"
: "evento de exceção recorrente"

, "has alarm"
: "tem alarme"

, "has attachments"
: ""

, "is part of an open poll"
: ""

, "Mini Calendar"
: "Mini Calendário"

, "WK"
: "WK"

, "{0} more..."
: "{0} mais..."

, "Resource Grant, Resource Grants"
: [
  ""
 ,""

]
, "Invite Resource"
: ""

, "The grant to invite the resource to an event"
: ""

, "Read Resource"
: ""

, "The grant to read the resource itself"
: ""

, "Edit Resource"
: ""

, "The grant to edit the resource itself"
: ""

, "Export Resource"
: ""

, "The grant to export the resource itself"
: ""

, "Sync Resource"
: ""

, "The grant to synchronise the resource itself"
: ""

, "Resource Admin"
: ""

, "The grant to administrate the resource itself"
: ""

, "Add Events"
: ""

, "The grant to directly add events into this resource calendar"
: ""

, "Read Events"
: ""

, "The grant to read events from this resource calendar"
: ""

, "Export Events"
: ""

, "The grant to export events from this resource calendar"
: ""

, "Sync Events"
: ""

, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
: ""

, "Events Free Busy"
: ""

, "The grant to get free/busy information of events from this resource calendar"
: ""

, "Edit Events"
: ""

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: ""

, "Delete Events"
: ""

, "The grant to delete events directly stored in this resource calendar"
: ""

, "Free Busy"
: ""

, "The grant to get free/busy information of events in this calendar"
: ""

, "The grant to access events marked as private in this calendar"
: ""

, "Rrule"
: ""

, "Please choose the Event to add the contacts to"
: "Favor escolher o Evento para adicionar os contatos"

, "Role"
: "Função"

, "Select Role"
: "Selecionar Função"

, "Status"
: "Situação"

, "Select Status"
: "Selecionar estado"

, "Adding {0} Attendee to event"
: "Adicionando {0} Participante ao evento"

, "no events found"
: "nenhum evento encontrado"

, "Searching..."
: "Pesquisando..."

, "Search Event"
: "Pesquisar Evento"

, "Event, Events"
: [
  "Evento"
 ,"Eventos"

]
, "Additional Tags ..."
: ""

, "non-blocking"
: "sem bloqueio"

, "Displayed in"
: "Exibido em"

, "No Information"
: "Sem informação"

, "Event Location"
: ""

, "From"
: ""

, "until"
: ""

, "Events"
: "Eventos"

, "Calendars"
: "Calendários"

, "Quick Search"
: "Busca Rápida"

, "GENDER_Calendar"
: ""

, "Attendee Status"
: "Situação do Participante"

, "GENDER_Attendee Status"
: ""

, "Attendee Role"
: "Função do Participante"

, "GENDER_Attendee Role"
: ""

, "GENDER_Status"
: ""

, "GENDER_Blocking"
: ""

, "Classification"
: "Classificação"

, "GENDER_Classification"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Unknown date"
: "Data desconhecida"

, "{0} {1} o'clock"
: "{0} {1} horas"

, "Event (as attendee)"
: "Evento (como participante)"

, "Event (as organizer)"
: "Evento (como organizador)"

, "Event attendee"
: "Participante do Evento"

, "Attender, Attendee"
: [
  "Participante"
 ,"Participantes"

]
, "Resource, Resources"
: [
  "Recurso"
 ,"Recursos"

]
, "Resources"
: "Recursos"

, "Anyone"
: ""

, "Name"
: "Nome"

, "Calendar Hierarchy/Name"
: ""

, "Email"
: "Email"

, "Maximum number of attendee"
: ""

, "Type"
: "Tipo"

, "Default attendee status"
: ""

, "Busy Type"
: ""

, "Event finder options"
: ""

, "Click here to invite another attender..."
: "Clique aqui para convidar outro participante..."

, "User"
: "Usuário"

, "Group"
: "Grupo"

, "Member of group"
: "Membro do grupo"

, "This is the calendar where the attender has saved this event in"
: "Este é o calendário onde o participante salvou este evento no"

, "Click icon to change"
: ""

, "Availability of Attendee"
: ""

, "Whole Group or each Member of Group"
: ""

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: ""

, "Member of Group"
: ""

, "Loading Groupmembers..."
: ""

, "Remove Attender"
: "Remover Participante"

, "Compose email"
: ""

, "Poll URL: {0}"
: ""

, "View Resource"
: ""

, "(as a group member)"
: "(como um membro do grupo)"

, "External Attendee"
: "Participante Externo"

, "Originally"
: "Originalmente"

, "Checking Calendar Data..."
: "Checando Dados do Calendário..."

, "Reply to Recurring Event"
: "Responder ao Evento Recorrente"

, "You are responding to an recurring event. What would you like to do?"
: "Você está respondendo a um evento recorrente.  O que você quer fazer?"

, "Respond to whole series"
: "Responder para series inteiras"

, "Do not respond"
: "Não responda"

, "The event of this message does not exist"
: "O evento dessa mensagem não existe"

, "The sender is not authorised to update the event"
: "O remetente não está autorizado a atualizar o evento"

, "This message is already processed"
: "Esta mensagem já foi processada"

, "You are not an attendee of this event"
: "Você não é participante deste evento"

, "This event has been deleted by the organizer"
: ""

, "This event has been canceled."
: "Este evento foi cancelado"

, "Unsupported message"
: "Mensagem não suportada"

, "This is an event invitation for someone else."
: "Este é um convite de evento para alguém."

, "You have already replied to this event invitation."
: "Você já respondeu a este convite de evento"

, "The event got rescheduled. Set your response to:"
: ""

, "You received an event invitation. Set your response to:"
: "Você recebeu um convite para evento. Enviar sua resposta para:"

, "An invited attendee responded to the invitation."
: "Um participante convidado respondeu ao convite."

, "Unsupported method"
: "Método não suportado"

, "Suppress notification"
: ""

, "Color"
: ""

, "Enter description..."
: "Informar descrição..."

, "Grants"
: "Concessões"

, "This event is originally stored in a calendar you don't have access to."
: "Este evento foi originalmente carregado no calendário e você não tem acesso"

, "This event is originally stored in {0}"
: "Este evendo foi originalmente carregado em {0}"

, "This event is additionally displayed in your personal calendar {0}"
: "Este evento foi exibido adicionalmente no seu calendário pessoal {0}"

, "Colors"
: "Cores"

, "Side bar color"
: ""

, "Color by Calendar"
: ""

, "Color by Attendee Calendar"
: ""

, "Color by Tags"
: ""

, "Color by Attendee Role"
: ""

, "Colors by response"
: ""

, "Colors by tags"
: ""

, "Colors by attendee"
: ""

, "Colors by resource"
: ""

, "View"
: "Visão"

, "Saved in"
: "Salvo em"

, "Enter description"
: "Informe a descrição"

, "Notifications are disabled"
: ""

, "Notifications are enabled"
: ""

, "Print Event"
: ""

, "Send Notification?"
: ""

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "End date is not valid"
: "Data final não é válida"

, "End date must be after start date"
: "Data final deve ser posterior à data de início"

, "End time is not allowed to be after the configured time."
: ""

, "Start date is not valid"
: "Data de início não é válida"

, "Start date is not allowed to be before the configured time."
: ""

, "The summary must not be longer than 255 characters."
: "O sumário não pode ter mais que 255 caracteres"

, "The summary must have at least 1 character."
: "O sumário deve ter pelo menos 1 caracter."

, "Summary too Long"
: "Sumário é muito grande"

, "Summary too Short"
: "Sumário muito pequeno"

, "Set This Date as Definite Event?"
: ""

, "Do you want to close the poll and remove all other alternatives?"
: ""

, "Attendee/Resources"
: ""

, "Additional Attendees ..."
: ""

, "Default Status"
: ""

, "No Access"
: ""

, "All my events"
: "Todos os meus eventos"

, "Position on the left time axis, day and week view should start with"
: "Posição no eixo de tempo esquerdo, visão do dia e da semana deve começar com"

, "Position on the left time axis, day and week view should end with"
: ""

, "Default Start Time"
: ""

, "Scroll position on the left time axis, day and week view should start with"
: ""

, "Visible Time"
: ""

, "Time to be displayed at once"
: ""

, "Default Calendar"
: "Calendário Padrão"

, "The default calendar for invitations and new events"
: "O calendário padrão para convites e novos eventos"

, "Default Favorite"
: "Favorito Padrão"

, "The default favorite which is loaded on calendar startup"
: "O favorito padrão que foi carregado no calendário de inicialização"

, "Get Notification Emails"
: "Obter Emails de Notificações"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "O nível de ações que você quer ser notificado.  Favor observe que a menos que esta preferência esteja assinalado no \"Nunca\""

, "Send Notifications Emails of own Actions"
: "Enviar Emails de Notificações das suas próprias Ações"

, "Get notifications emails for actions you did yourself"
: "Obter emails de notificações feitos por você mesmo"

, "Send Notifications Emails of tentative events"
: ""

, "Get notifications emails of tentative events"
: ""

, "Send Alarm Notifications Emails"
: ""

, "Get event alarms via email"
: ""

, "Enable Standard Alarm"
: "Ativar Alarme Padrão"

, "New events get a standard alarm as defined below"
: "Novos eventos têm um padrão de alarme como definido abaixo"

, "Standard Alarm Time"
: "Hora do Alarme Padrão"

, "Minutes before the event starts"
: "Minutos antes do evento começar"

, "Default Attendee Strategy"
: ""

, "Default Attendee Strategy for new events"
: ""

, "Time Increment"
: ""

, "Increment of event time steps"
: ""

, "Default set Events to privat"
: ""

, "If enabled every created event is always privat"
: ""

, "First Day of Week"
: ""

, "On what day the week should be starting"
: ""

, "Default calendar strategy"
: ""

, "The calendar for new events if no container is selected"
: ""

, "Fixed Calendars"
: "Calendários fixos"

, "Calendars always selected regardless of all filter parameters."
: ""

, "Never"
: "Nunca"

, "On invitation and cancellation only"
: "A convite e cancelamento somente"

, "On time changes"
: "Mudanças na hora"

, "On all updates but attendee responses"
: "Em todas as atualizações mas respostas dos participantes"

, "On attendee responses too"
: "Em respostas dos participantes também"

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: "Calendários sempre selecionados independentemente de todos os parâmetros de filtro. Um caso de utilização válida poderia ser a de forçar a apresentação de um certo calendário de férias."

, "Crop Days"
: ""

, "Crop calendar view configured start and endtime."
: ""

, "Crop Days Limit Override"
: ""

, "Allow events outside start and endtime."
: ""

, "Week View Mouse Wheel Increment"
: ""

, "Default View for Events"
: ""

, "Event Status Available"
: ""

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: ""

, "Confirmed"
: ""

, "Canceled"
: ""

, "Event Classes Available"
: ""

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: ""

, "Public"
: ""

, "Confidential"
: ""

, "Event Transparencies Available"
: ""

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: ""

, "Transparent"
: ""

, "Opaque"
: ""

, "Attendee Status Available"
: "Situação de Participante Disponível"

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: ""

, "No response"
: "Sem resposta"

, "Accepted"
: "Aceito"

, "Declined"
: "Recusado"

, "Attendee Roles Available"
: "Funções de Participante Disponíveis"

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: ""

, "Required"
: "Exigido"

, "Optional"
: "Opcional"

, "Organizer has implicit edit grant"
: ""

, "Resource Types Available"
: ""

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Room"
: ""

, "Board"
: ""

, "Cable"
: ""

, "Car"
: ""

, "Coffee"
: ""

, "Homeoffice"
: ""

, "Lamp"
: ""

, "Laptop"
: ""

, "Material"
: ""

, "Projector"
: ""

, "Travel"
: ""

, "Free/Busy Types Available"
: ""

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Free"
: ""

, "Busy"
: ""

, "Filter timeslot for CalDAV events"
: ""

, "For how long in the past (in months) the events should be synchronized."
: "Por quanto tempo no passado (em meses) os eventos devem ser sincronizados"

, "Filter timeslot for CalDAV events with SyncToken"
: ""

, "Timeslot for event notifications"
: ""

, "For how long in the past (in weeks) event notifications should be sent."
: ""

, "Default filter period (from) for events fetched via JSON API"
: ""

, "For how long in the past (in months) the events should be fetched."
: ""

, "Default filter period (until) for events fetched via JSON API"
: ""

, "For how long in the future (in months) the events should be fetched."
: ""

, "Disable iMIP for external organizers"
: ""

, "Disable notification for external organizers"
: ""

, "(CalDAV) Skip double events from personal or shared calendar"
: ""

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: ""

, "Send notifications to every user with edit permissions of the added resources"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee"
: ""

, "Calendar Year View"
: ""

, "Adds year view to Calendar"
: ""

, "Calendar Extended Context Menu Actions"
: ""

, "Adds extended actions to event context menus"
: ""

, "Color Events By"
: ""

, "Choose event color by different criteria"
: ""

, "Recur Events Except"
: ""

, "Recur Events except on certain dates"
: ""

, "Activate Poll for Events"
: ""

, "Create alternative Events and let users as well as externals vote for the best option."
: ""

, "Lead Notification Confirmation"
: ""

, "Send Tentative Notifications"
: ""

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: ""

, "Enabled"
: ""

, "Days Before Due Date"
: ""

, "How many days before the events due date to start send notifications."
: ""

, "Additional Filter"
: ""

, "Additional filter to limit events notifications should be send for."
: ""

, "Mute Event Notifications for Polls"
: ""

, "Do not send invitations notifications for alternative events in an active poll."
: ""

, "GTCs for polls"
: ""

, "Freebusy Info"
: ""

, "What data the freebusy grant reveals"
: ""

, "only date & time"
: ""

, "and organizer"
: ""

, "and resources"
: ""

, "and calendar"
: ""

, "and other attendees"
: ""

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "%s's personal calendar"
: "Calendário pessoal de %s"

, "Failed"
: ""

, "The right Resource Admin must be set once."
: ""

, "Different Calendar"
: ""

, "Exdate container move are not allowed"
: ""

, "Invalid URL given"
: ""

, "The URL you used is invalid. Please use a valid one!"
: "A URL que você usou é inválida. Por favor use uma válida!"

, "Calendars to export"
: ""

, "Export target"
: ""

, "VCalendar/ICS"
: ""

, "Export visible events to ics file"
: ""

, "Excel overview"
: ""

, "Word event sheet"
: ""

, "Export Events as Calendar Sheet"
: ""

, "VCalendar Report"
: ""

, "Export multiple calendars to ics files"
: ""

, "OpenDocument all data"
: ""

, "Export event data into ods spreadsheet"
: ""

, "Word details"
: ""

, "Excel all data"
: ""

, "Shared Calendar CSV"
: ""

, "Resource CSV"
: ""

, "You can not have more than one grants filter"
: ""

, "Import iCal-files"
: "Importar Arquivos iCal"

, "unknown"
: "desconhecido"

, "This contact has been automatically added by the system as an event attender"
: "Este contato foi automaticamente adicionado pelo sistema como um evento de participante"

, "The email address has been shortened:"
: ""

, "Every %s day"
: "Todo dia %s"

, "Every %s week on"
: ""

, "Weekly on"
: ""

, "and"
: ""

, "Every %1$s month on the %2$s %3$s"
: ""

, "Monthly every %1$s %2$s"
: ""

, "Every %1$s month on the %2$s"
: ""

, "Monthly on the %1$s"
: ""

, "Yearly every %1$s %2$s of %3$s"
: ""

, "Yearly on the %1$s of %2$s"
: ""

, "second to last"
: ""

, "fifth"
: "quinto"

, "st"
: ""

, "nd"
: ""

, "rd"
: ""

, "th"
: ""

, "Start"
: "Início"

, "Priority"
: "Prioridade"

, "Url"
: "Url"

, "Recurrance rule"
: "Regra de recorrência"

, "Is all day event"
: "São todos os eventos do dia"

, "Organizer timezone"
: "Fuso horário organizador"

, "Locked"
: ""

, "Closed"
: ""

, "Alarm for event \"%1$s\" at %2$s"
: "Alarme para eventos \"%1$s\" at %2$s"

, "Event invitation \"%1$s\" at %2$s"
: "Convite para Eventos \"%1$s\" em %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: "Recurso \"%1$s\" foi reservado por \"%2$s\" em %3$s"

, "Event \"%1$s\" at %2$s has been canceled"
: "Eventos \"%1$s\" em %2$s foi cancelado"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: "Evento \"%1$s\" foi reagendado de %2$s para %3$s"

, "Event \"%1$s\" at %2$s has been updated"
: "Evento \"%1$s\" em  %2$s foi atualizado"

, "%1$s accepted event \"%2$s\" at %3$s"
: "%1$s aceitou evento \"%2$s\" em %3$s"

, "%1$s declined event \"%2$s\" at %3$s"
: "%1$s evento recusado \"%2$s\" em %3$s"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: "Tentativa de resposta de %1$s para o \"%2$s\" em %3$s"

, "No response from %1$s for event \"%2$s\" at %3$s"
: "Nenhuma resposta de %1$s para o evento \"%2$s\" em %3$s"

, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
: ""

, "Attendee changes for event \"%1$s\" at %2$s"
: "Modificações de participante para o evento \"%1$s\" em %2$s"

, "Tentative event notification for event \"%1$s\" at %2$s"
: ""

, "Unknown action"
: ""

, "Resource Management"
: ""

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: ""

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: ""

, "Attendance Confirmation for Poll \"%1$s\""
: ""

, "%1$s is scheduled for %2$s"
: ""

, "The poll \"%1$s\" has been closed."
: ""

, "The definite event is scheduled for \"%1$s\""
: ""

, "You can review the poll results here:"
: ""

, "Thank you for attendening the poll \"%1$s\""
: ""

, "To review or edit your status please use your personal link:"
: ""

, "Updates"
: "Atualizados"

, "This is an event series exception."
: ""

, "%1$s changed from \"%2$s\" to \"%3$s\""
: "%1$s modificado de \"%2$s\" para \"%3$s\""

, "%1$s has been invited"
: "%1$s foi enviado"

, "%1$s has been removed"
: "%1$s foi removido"

, "%1$s accepted invitation"
: "%1$s convite aceito"

, "%1$s declined invitation"
: "%1$s convite recusado"

, "Tentative response from %1$s"
: "Tentativa de resposta de %1$s"

, "No response from %1$s"
: "Nenhuma resposta de %1$s"

, "\"%2$s\" response from %1$s"
: "\"%2$s\" resposta de %1$s"

, "Link"
: ""

, "Event details"
: "Detalhes do evento"

, "All events I attend"
: "Todos os eventos que eu participo"

, "Awaiting response"
: "Aguardando resposta"

, "Events I have not yet responded to"
: "Eventos que eu ainda não tenho resposta"

, "Declined events"
: "Eventos recusados"

, "Events I have declined"
: "Eventos que eu recusei"

, "I'm organizer"
: "Eu sou organizador"

, "Events I'm the organizer of"
: "Eventos que eu sou organizador de"

, "manage shared calendars"
: "administrar calendários compartilhados"

, "Create new shared calendars"
: "Criar novos calendários compartilhados"

, "manage shared calendars favorites"
: "gerenciar calendários favoritos compartilhados"

, "Create or update shared calendars favorites"
: "Criar ou atualizar calendários favoritos compartilhados"

, "manage resources"
: "gerenciar recursos"

, "All Rights to administrate resources"
: "Todos os direitos para administrar recursos"

, "Account"
: ""

, "Exporttime"
: ""

, "First name, ĺast name"
: ""

, "E-Mail address"
: ""

, "Please wait..."
: ""

, "General terms and conditions"
: ""

, "0009326B"
: ""

, "20"
: ""

, "00B359B9"
: ""

, "00997199"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "Poll"
: ""

, "Calendar"
: "Calendário"

, "Do you really want to delete this event?"
: "Você quer realmente apagar este evento?"

, "Resource Grant"
: ""

, "Event"
: "Evento"

, "Attender"
: "Participante"

, "Resource"
: "Recurso"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
